@@ -1,7 +1,7 @@
 import ast
 import os
 import sys
-import distutils
+from distutils import sysconfig
 import pkg_resources
 import xmlrpclib
 import sh
@@ -20,9 +20,9 @@ class DepsFinder(object):
         self.unknown_mods = []
         self.guessed_mods = {}
         self.suggested_mods = {}
-        self.std_path = distutils.sysconfig.get_python_lib(standard_lib=True, prefix=os.path.realpath(sys.prefix))
-        self.std_path2 = distutils.sysconfig.get_python_lib(standard_lib=True)
-        self.third_path = distutils.sysconfig.get_python_lib(standard_lib=False)
+        self.std_path = sysconfig.get_python_lib(standard_lib=True, prefix=os.path.realpath(sys.prefix))
+        self.std_path2 = sysconfig.get_python_lib(standard_lib=True)
+        self.third_path = sysconfig.get_python_lib(standard_lib=False)
         self.guess_files = guess_files
         self.cal_deps(self.mainfile)
 
